<?php

namespace Drupal\content_moderation_info_block\Form;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\content_moderation\Form\EntityModerationForm;

/**
 * Provides a simple UI for changing moderation state.
 */
class ContentModerationInfoBlockForm extends EntityModerationForm {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'content_moderation_info_block_form';
  }

  /**
   * Form constructor.
   *
   * This form is the same as the original entity moderation form
   * ('content_moderation_entity_moderation_form'), with a few minor
   * alterations.
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   * @param \Drupal\Core\Entity\ContentEntityInterface|null $entity
   *   (optional) The entity object to display the form for.
   * @param bool $revision_log_message
   *   (optional) If TRUE, a revision log message can be input. Defaults to
   *   TRUE.
   *
   * @return array
   *   The form structure.
   */
  public function buildForm(array $form, FormStateInterface $form_state, ContentEntityInterface $entity = NULL, $revision_log_message = TRUE) {
    $form = parent::buildForm($form, $form_state, $entity);

    $form['current']['#access'] = FALSE;

    $form['new_state']['#title'] = $this->t('Action');

    // Use the transition labels in the options instead of the state labels.
    /** @var \Drupal\workflows\Transition[] $transitions */
    $transitions = $this->validation->getValidTransitions($entity, $this->currentUser());
    foreach ($transitions as $transition) {
      $target_state_id = $transition->to()->id();
      if (!empty($form['new_state']['#options'][$target_state_id])) {
        $form['new_state']['#options'][$target_state_id] = $transition->label();
      }
    }

    $form['revision_log']['#access'] = $revision_log_message;

    unset($form['#theme']);

    $key = array_search('content_moderation/content_moderation', $form['#attached']['library'], TRUE);
    if ($key !== FALSE) {
      unset($form['#attached']['library'][$key]);
    }

    return $form;
  }

}
